# Change log

## `v0.3.0` - 2023-04-03

### Features
- `PyscfCalculation`: Add support for writing FCIDUMP files [[#17]](https://github.com/microsoft/aiida-pyscf/pull/17)
- `PyscfCalculation`: Add support for computing orbital cube files [[#20]](https://github.com/microsoft/aiida-pyscf/pull/20)
- `PyscfCalculation`: Ensure strings are rendered with quotes in templates [[#19]](https://github.com/microsoft/aiida-pyscf/pull/19)
- `PyscfCalculation`: Add validation for `optimizer` parameters [[#16]](https://github.com/microsoft/aiida-pyscf/pull/16)
- `PyscfCalculation`: Refactor to simplify subclassing [[#22]](https://github.com/microsoft/aiida-pyscf/pull/22)

### Documentation
- Docs: Add setup and run instructions to `README.md` [[#18]](https://github.com/microsoft/aiida-pyscf/pull/18)
- Docs: Add badges and table of contents to `README.md` [[#23]](https://github.com/microsoft/aiida-pyscf/pull/23)

### Devops
- CI: Update `pip` and install `wheel` [[#21]](https://github.com/microsoft/aiida-pyscf/pull/21)


## `v0.2.0` - 2023-03-28

### Improvements
- `PyscfCalculation`: Use `PrefixLoader` for template environment loader [[#12]](https://github.com/microsoft/aiida-pyscf/pull/12)
- `PyscfCalculation`: Improve white-space in rendered script [[#13]](https://github.com/microsoft/aiida-pyscf/pull/13)


## `v0.1.0` - 2023-03-27

First release of the package.
